// Jason Rohrer
// SearchResultsTable.java

/**
*
*	Table of search results (FileDescriptorGUI's), with buttons to start downloads
*
*	Created 5-11-2000
*	Mods:
*		Jason Rohrer	6-1-2000	Changed to filter results so that files on this
*									host don't appear
*		Jason Rohrer	6-14-2000	Removed filtering against files on this host.
*									This functionality has been moved server-side
*									to ensure that search results are comprehensive.
*/

package konspire.client;

import konspire.common.SearchResults;
import konspire.common.FileDescriptor;
import konspire.common.Host;

import konspire.common.Vector;
import java.util.Enumeration;
import java.util.NoSuchElementException;

import javax.swing.JButton;

/**
 * Table of search reulsts.  Contains a {@link FileDescriptorGUI} for each result
 * file.
 *
 * @author Jason Rohrer
 */
public class SearchResultsTable extends ScrollTablePanel {


	String colTitles[] = { "file name", "size", "" };
	
	Class colClasses[] = { String.class, String.class, JButton.class }; 

	String tableTitle = "search results";
	
	DownloadController parent;
	
	/**
	 * Construct a <code>SearchResultsTable</code>
	 *
	 * @param par parent download controler responsible for downloading files
	 * selected by user.
	 */
	public SearchResultsTable( DownloadController par ) {
		super();
		// setup superclass ScrollTablePanel
		setup( tableTitle, colTitles, colClasses );
		parent = par;
		}
		
	/**
	 * Displays search results.
	 *
	 * @param sR results to display
	 */
	public void displayResults( SearchResults sR ) {
		removeAllRows();	// clear current table
		
		Vector fileV = sR.getFileVector();
		String searchTerms[] = sR.getSearchTerms();
		
		if( searchTerms.length > 0 ) {
			String searchString = searchTerms[0];
			
			for( int i=1; i<searchTerms.length; i++ ) {
				searchString += ", " + searchTerms[i];
				}
			setSubtitle( searchString );	// display search terms in title of table
			}
		
		// enumerate through fileV and add file descriptor rows to table
		Enumeration e = fileV.elements();	
		
		try {
			while( e.hasMoreElements() ) {
				FileDescriptor f = (FileDescriptor)( e.nextElement() );
				new FileDescriptorGUI( f, this );	// gui row will add itself to table
				}
			}
		catch( NoSuchElementException ex ) {
			System.out.println( "Iterating through search results vector failed: " + ex.toString() );
			}
		}	// end displayResults()
		
		
	/**
	 * Callback from a row in table when download button is pressed
	 */
	public void startDownload( FileDescriptor f ) {
		// pass on to client
		parent.startDownload( f );
		}
	
	/**
	 * Set title displayed after "search results: ".  Usually used to display
	 * string that was matched to produce the current results.
	 *
	 * @param subtitle title to display after main panel title
	 */	
	private void setSubtitle( String subtitle ) {
		if( subtitle.length() == 0 ) {
			// remove subtitle
			setTitle( tableTitle );
			}
		else {
			// add/change subtitle
			setTitle( tableTitle + ": " + subtitle );
			}
		repaint();
		}	
		
	}